==> bo4e-0.2.1.tar.gz: bo4e-0.2.1/src/bo4e/com/standorteigenschaftenstrom.py <==
"""
Contains StandorteigenschaftenStrom class
and corresponding marshmallow schema for de-/serialization
"""

import attr
from marshmallow import fields

from bo4e.com.com import COM, COMSchema


# pylint: disable=too-few-public-methods
@attr.s(auto_attribs=True, kw_only=True)
class StandorteigenschaftenStrom(COM):
    """
    Standorteigenschaften der Sparte Strom

    .. HINT::
        `StandorteigenschaftenStrom JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/StandorteigenschaftenStromSchema.json>`_
    """

    # required attributes
    #: Die EIC-Nummer des Bilanzierungsgebietes
    bilanzierungsgebiet_eic: str = attr.ib(validator=attr.validators.instance_of(str))
    # todo: use EIC validation: https://github.com/Hochfrequenz/BO4E-python/issues/147

    #: Der Name der Regelzone
    regelzone: str = attr.ib(validator=attr.validators.instance_of(str))

    #: De EIC-Nummer der Regelzone
    regelzone_eic: str = attr.ib(validator=attr.validators.instance_of(str))
    # todo: use EIC validation: https://github.com/Hochfrequenz/BO4E-python/issues/147


class StandorteigenschaftenStromSchema(COMSchema):
    """
    Schema for de-/serialization of StandorteigenschaftenStrom.
    """

    class_name = StandorteigenschaftenStrom
    # required attributes
    bilanzierungsgebiet_eic = fields.Str(data_key="bilanzierungsgebietEic")
    regelzone = fields.Str()
    regelzone_eic = fields.Str(data_key="regelzoneEic")

==> bo4e-0.2.5.tar.gz: bo4e-0.2.5/src/bo4e/com/standorteigenschaftenstrom.py <==
"""
Contains StandorteigenschaftenStrom class
and corresponding marshmallow schema for de-/serialization
"""

import attr
from marshmallow import fields

from bo4e.com.com import COM, COMSchema


# pylint: disable=too-few-public-methods
@attr.s(auto_attribs=True, kw_only=True)
class StandorteigenschaftenStrom(COM):
    """
    Standorteigenschaften der Sparte Strom

    .. HINT::
        `StandorteigenschaftenStrom JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/StandorteigenschaftenStromSchema.json>`_

    """

    # required attributes
    #: Die EIC-Nummer des Bilanzierungsgebietes
    bilanzierungsgebiet_eic: str = attr.ib(validator=attr.validators.instance_of(str))
    # todo: use EIC validation: https://github.com/Hochfrequenz/BO4E-python/issues/147

    #: Der Name der Regelzone
    regelzone: str = attr.ib(validator=attr.validators.instance_of(str))

    #: De EIC-Nummer der Regelzone
    regelzone_eic: str = attr.ib(validator=attr.validators.instance_of(str))
    # todo: use EIC validation: https://github.com/Hochfrequenz/BO4E-python/issues/147


class StandorteigenschaftenStromSchema(COMSchema):
    """
    Schema for de-/serialization of StandorteigenschaftenStrom.
    """

    class_name = StandorteigenschaftenStrom
    # required attributes
    bilanzierungsgebiet_eic = fields.Str(data_key="bilanzierungsgebietEic")
    regelzone = fields.Str()
    regelzone_eic = fields.Str(data_key="regelzoneEic")
